import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApiFilterConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the External Endpoint where this API Filter will process the requests to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter#external_endpoint_id ApiFilter#external_endpoint_id}
    */
    readonly externalEndpointId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter#id ApiFilter#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Request URL pattern, written as a regular expression pattern
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter#url_matcher_pattern ApiFilter#url_matcher_pattern}
    */
    readonly urlMatcherPattern: string;
    /**
    * Allowed values are EXT_API, EXT_UI_PROVIDER, EXT_UI_TENANT corresponding to /ext-api, /ext-ui/provider, /ext-ui/tenant/<tenant-name>
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter#url_matcher_scope ApiFilter#url_matcher_scope}
    */
    readonly urlMatcherScope: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter vcd_api_filter}
*/
export declare class ApiFilter extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_api_filter";
    /**
    * Generates CDKTF code for importing a ApiFilter resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ApiFilter to import
    * @param importFromId The id of the existing ApiFilter that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ApiFilter to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/api_filter vcd_api_filter} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ApiFilterConfig
    */
    constructor(scope: Construct, id: string, config: ApiFilterConfig);
    private _externalEndpointId?;
    get externalEndpointId(): string;
    set externalEndpointId(value: string);
    get externalEndpointIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _urlMatcherPattern?;
    get urlMatcherPattern(): string;
    set urlMatcherPattern(value: string);
    get urlMatcherPatternInput(): string | undefined;
    private _urlMatcherScope?;
    get urlMatcherScope(): string;
    set urlMatcherScope(value: string);
    get urlMatcherScopeInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
