import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataVcdOrgOidcConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/data-sources/org_oidc#id DataVcdOrgOidc#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Organization ID that has the OpenID Connect settings
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/data-sources/org_oidc#org_id DataVcdOrgOidc#org_id}
    */
    readonly orgId: string;
}
export interface DataVcdOrgOidcClaimsMapping {
}
export declare function dataVcdOrgOidcClaimsMappingToTerraform(struct?: DataVcdOrgOidcClaimsMapping): any;
export declare function dataVcdOrgOidcClaimsMappingToHclTerraform(struct?: DataVcdOrgOidcClaimsMapping): any;
export declare class DataVcdOrgOidcClaimsMappingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdOrgOidcClaimsMapping | undefined;
    set internalValue(value: DataVcdOrgOidcClaimsMapping | undefined);
    get email(): string;
    get firstName(): string;
    get fullName(): string;
    get groups(): string;
    get lastName(): string;
    get roles(): string;
    get subject(): string;
}
export declare class DataVcdOrgOidcClaimsMappingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdOrgOidcClaimsMappingOutputReference;
}
export interface DataVcdOrgOidcKey {
}
export declare function dataVcdOrgOidcKeyToTerraform(struct?: DataVcdOrgOidcKey): any;
export declare function dataVcdOrgOidcKeyToHclTerraform(struct?: DataVcdOrgOidcKey): any;
export declare class DataVcdOrgOidcKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataVcdOrgOidcKey | undefined;
    set internalValue(value: DataVcdOrgOidcKey | undefined);
    get algorithm(): string;
    get certificate(): string;
    get expirationDate(): string;
    get id(): string;
}
export declare class DataVcdOrgOidcKeyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataVcdOrgOidcKeyOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/data-sources/org_oidc vcd_org_oidc}
*/
export declare class DataVcdOrgOidc extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "vcd_org_oidc";
    /**
    * Generates CDKTF code for importing a DataVcdOrgOidc resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataVcdOrgOidc to import
    * @param importFromId The id of the existing DataVcdOrgOidc that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/data-sources/org_oidc#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataVcdOrgOidc to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/data-sources/org_oidc vcd_org_oidc} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataVcdOrgOidcConfig
    */
    constructor(scope: Construct, id: string, config: DataVcdOrgOidcConfig);
    get accessTokenEndpoint(): string;
    private _claimsMapping;
    get claimsMapping(): DataVcdOrgOidcClaimsMappingList;
    get clientId(): string;
    get clientSecret(): string;
    get enabled(): cdktf.IResolvable;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get issuerId(): string;
    private _key;
    get key(): DataVcdOrgOidcKeyList;
    get keyExpireDurationHours(): number;
    get keyRefreshEndpoint(): string;
    get keyRefreshPeriodHours(): number;
    get keyRefreshStrategy(): string;
    get maxClockSkewSeconds(): number;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    get preferIdToken(): cdktf.IResolvable;
    get redirectUri(): string;
    get scopes(): string[];
    get uiButtonLabel(): string;
    get userAuthorizationEndpoint(): string;
    get userinfoEndpoint(): string;
    get wellknownEndpoint(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
