import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DseRegistryConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Chart repository to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#chart_repository DseRegistryConfiguration#chart_repository}
    */
    readonly chartRepository?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#id DseRegistryConfiguration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Data Solution Name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#name DseRegistryConfiguration#name}
    */
    readonly name?: string;
    /**
    * Package name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#package_name DseRegistryConfiguration#package_name}
    */
    readonly packageName?: string;
    /**
    * Package repository to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#package_repository DseRegistryConfiguration#package_repository}
    */
    readonly packageRepository?: string;
    /**
    * Use the default settings as provided by the Data Solution
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#use_default_values DseRegistryConfiguration#use_default_values}
    */
    readonly useDefaultValues?: boolean | cdktf.IResolvable;
    /**
    * Version of package to use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#version DseRegistryConfiguration#version}
    */
    readonly version?: string;
    /**
    * container_registry block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#container_registry DseRegistryConfiguration#container_registry}
    */
    readonly containerRegistry?: DseRegistryConfigurationContainerRegistry[] | cdktf.IResolvable;
}
export interface DseRegistryConfigurationContainerRegistry {
    /**
    * Registry description
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#description DseRegistryConfiguration#description}
    */
    readonly description: string;
    /**
    * Registry host
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#host DseRegistryConfiguration#host}
    */
    readonly host: string;
    /**
    * Password for registry user
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#password DseRegistryConfiguration#password}
    */
    readonly password?: string;
    /**
    * Username for registry access
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#username DseRegistryConfiguration#username}
    */
    readonly username?: string;
}
export declare function dseRegistryConfigurationContainerRegistryToTerraform(struct?: DseRegistryConfigurationContainerRegistry | cdktf.IResolvable): any;
export declare function dseRegistryConfigurationContainerRegistryToHclTerraform(struct?: DseRegistryConfigurationContainerRegistry | cdktf.IResolvable): any;
export declare class DseRegistryConfigurationContainerRegistryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DseRegistryConfigurationContainerRegistry | cdktf.IResolvable | undefined;
    set internalValue(value: DseRegistryConfigurationContainerRegistry | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
}
export declare class DseRegistryConfigurationContainerRegistryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DseRegistryConfigurationContainerRegistry[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DseRegistryConfigurationContainerRegistryOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration vcd_dse_registry_configuration}
*/
export declare class DseRegistryConfiguration extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_dse_registry_configuration";
    /**
    * Generates CDKTF code for importing a DseRegistryConfiguration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DseRegistryConfiguration to import
    * @param importFromId The id of the existing DseRegistryConfiguration that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DseRegistryConfiguration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_registry_configuration vcd_dse_registry_configuration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DseRegistryConfigurationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DseRegistryConfigurationConfig);
    private _chartRepository?;
    get chartRepository(): string;
    set chartRepository(value: string);
    resetChartRepository(): void;
    get chartRepositoryInput(): string | undefined;
    get compatibleVersionConstraints(): string[];
    get defaultChartRepository(): string;
    get defaultPackageName(): string;
    get defaultRepository(): string;
    get defaultVersion(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _packageName?;
    get packageName(): string;
    set packageName(value: string);
    resetPackageName(): void;
    get packageNameInput(): string | undefined;
    private _packageRepository?;
    get packageRepository(): string;
    set packageRepository(value: string);
    resetPackageRepository(): void;
    get packageRepositoryInput(): string | undefined;
    get rdeState(): string;
    get requiresVersionCompatibility(): cdktf.IResolvable;
    get type(): string;
    private _useDefaultValues?;
    get useDefaultValues(): boolean | cdktf.IResolvable;
    set useDefaultValues(value: boolean | cdktf.IResolvable);
    resetUseDefaultValues(): void;
    get useDefaultValuesInput(): boolean | cdktf.IResolvable | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _containerRegistry;
    get containerRegistry(): DseRegistryConfigurationContainerRegistryList;
    putContainerRegistry(value: DseRegistryConfigurationContainerRegistry[] | cdktf.IResolvable): void;
    resetContainerRegistry(): void;
    get containerRegistryInput(): cdktf.IResolvable | DseRegistryConfigurationContainerRegistry[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
