import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DseSolutionPublishConfig extends cdktf.TerraformMetaArguments {
    /**
    * Only for 'Confluent Platform'. Required if 'confluent_license_type = With License'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#confluent_license_key DseSolutionPublish#confluent_license_key}
    */
    readonly confluentLicenseKey?: string;
    /**
    * Only for 'Confluent Platform'. One of 'No License' or 'With License'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#confluent_license_type DseSolutionPublish#confluent_license_type}
    */
    readonly confluentLicenseType?: string;
    /**
    * The ID of Data Solution
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#data_solution_id DseSolutionPublish#data_solution_id}
    */
    readonly dataSolutionId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#id DseSolutionPublish#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A tenant ID that will get the Data Solution Published
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#org_id DseSolutionPublish#org_id}
    */
    readonly orgId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish vcd_dse_solution_publish}
*/
export declare class DseSolutionPublish extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_dse_solution_publish";
    /**
    * Generates CDKTF code for importing a DseSolutionPublish resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DseSolutionPublish to import
    * @param importFromId The id of the existing DseSolutionPublish that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DseSolutionPublish to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/dse_solution_publish vcd_dse_solution_publish} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DseSolutionPublishConfig
    */
    constructor(scope: Construct, id: string, config: DseSolutionPublishConfig);
    private _confluentLicenseKey?;
    get confluentLicenseKey(): string;
    set confluentLicenseKey(value: string);
    resetConfluentLicenseKey(): void;
    get confluentLicenseKeyInput(): string | undefined;
    private _confluentLicenseType?;
    get confluentLicenseType(): string;
    set confluentLicenseType(value: string);
    resetConfluentLicenseType(): void;
    get confluentLicenseTypeInput(): string | undefined;
    private _dataSolutionId?;
    get dataSolutionId(): string;
    set dataSolutionId(value: string);
    get dataSolutionIdInput(): string | undefined;
    get dsOrgConfigId(): string;
    get dsoAclId(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    get templateAclIds(): string[];
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
