import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ExternalEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the External Endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#description ExternalEndpoint#description}
    */
    readonly description?: string;
    /**
    * If 'true', the External Endpoint is disabled before deleting the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#disable_on_removal ExternalEndpoint#disable_on_removal}
    */
    readonly disableOnRemoval?: boolean | cdktf.IResolvable;
    /**
    * Whether the External Endpoint is enabled or not
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#enabled ExternalEndpoint#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#id ExternalEndpoint#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the External Endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#name ExternalEndpoint#name}
    */
    readonly name: string;
    /**
    * The URL which requests will be redirected to. It must be a valid URL using https protocol
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#root_url ExternalEndpoint#root_url}
    */
    readonly rootUrl: string;
    /**
    * Vendor of the External Endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#vendor ExternalEndpoint#vendor}
    */
    readonly vendor: string;
    /**
    * Version of the External Endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#version ExternalEndpoint#version}
    */
    readonly version: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint vcd_external_endpoint}
*/
export declare class ExternalEndpoint extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_external_endpoint";
    /**
    * Generates CDKTF code for importing a ExternalEndpoint resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ExternalEndpoint to import
    * @param importFromId The id of the existing ExternalEndpoint that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ExternalEndpoint to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/external_endpoint vcd_external_endpoint} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ExternalEndpointConfig
    */
    constructor(scope: Construct, id: string, config: ExternalEndpointConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _disableOnRemoval?;
    get disableOnRemoval(): boolean | cdktf.IResolvable;
    set disableOnRemoval(value: boolean | cdktf.IResolvable);
    resetDisableOnRemoval(): void;
    get disableOnRemovalInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rootUrl?;
    get rootUrl(): string;
    set rootUrl(value: string);
    get rootUrlInput(): string | undefined;
    private _vendor?;
    get vendor(): string;
    set vendor(value: string);
    get vendorInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
