import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MultisiteSiteAssociationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Data needed to associate this site to another
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association#association_data MultisiteSiteAssociation#association_data}
    */
    readonly associationData?: string;
    /**
    * Name of the file to be filled with association data for this site
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association#association_data_file MultisiteSiteAssociation#association_data_file}
    */
    readonly associationDataFile?: string;
    /**
    * How many minutes to keep checking for connection (0=no check)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association#connection_timeout_mins MultisiteSiteAssociation#connection_timeout_mins}
    */
    readonly connectionTimeoutMins?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association#id MultisiteSiteAssociation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association vcd_multisite_site_association}
*/
export declare class MultisiteSiteAssociation extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_multisite_site_association";
    /**
    * Generates CDKTF code for importing a MultisiteSiteAssociation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MultisiteSiteAssociation to import
    * @param importFromId The id of the existing MultisiteSiteAssociation that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MultisiteSiteAssociation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/multisite_site_association vcd_multisite_site_association} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MultisiteSiteAssociationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: MultisiteSiteAssociationConfig);
    get associatedSiteHref(): string;
    get associatedSiteId(): string;
    get associatedSiteName(): string;
    private _associationData?;
    get associationData(): string;
    set associationData(value: string);
    resetAssociationData(): void;
    get associationDataInput(): string | undefined;
    private _associationDataFile?;
    get associationDataFile(): string;
    set associationDataFile(value: string);
    resetAssociationDataFile(): void;
    get associationDataFileInput(): string | undefined;
    private _connectionTimeoutMins?;
    get connectionTimeoutMins(): number;
    set connectionTimeoutMins(value: number);
    resetConnectionTimeoutMins(): void;
    get connectionTimeoutMinsInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get status(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
