import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgOidcConfig extends cdktf.TerraformMetaArguments {
    /**
    * The access token endpoint of the OpenID Connect Identity Provider. If 'wellknown_endpoint' is set, this attribute overrides the obtained access token endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#access_token_endpoint OrgOidc#access_token_endpoint}
    */
    readonly accessTokenEndpoint?: string;
    /**
    * Client ID to use when talking to the OpenID Connect Identity Provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#client_id OrgOidc#client_id}
    */
    readonly clientId: string;
    /**
    * Client Secret to use when talking to the OpenID Connect Identity Provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#client_secret OrgOidc#client_secret}
    */
    readonly clientSecret: string;
    /**
    * Enables or disables OpenID Connect authentication for the specified Organization
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#enabled OrgOidc#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#id OrgOidc#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The issuer identifier of the OpenID Connect Identity Provider. If 'wellknown_endpoint' is set, this attribute overrides the obtained issuer identifier
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#issuer_id OrgOidc#issuer_id}
    */
    readonly issuerId?: string;
    /**
    * Defines the expiration period of the key, only when 'key_refresh_strategy=EXPIRE_AFTER'. Maximum is 24 hours
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#key_expire_duration_hours OrgOidc#key_expire_duration_hours}
    */
    readonly keyExpireDurationHours?: number;
    /**
    * Endpoint used to refresh the keys. If 'wellknown_endpoint' is set, then this argumentwill override the obtained endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#key_refresh_endpoint OrgOidc#key_refresh_endpoint}
    */
    readonly keyRefreshEndpoint?: string;
    /**
    * Defines the frequency of key refresh. Maximum is 720 hours
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#key_refresh_period_hours OrgOidc#key_refresh_period_hours}
    */
    readonly keyRefreshPeriodHours?: number;
    /**
    * Defines the strategy of key refresh
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#key_refresh_strategy OrgOidc#key_refresh_strategy}
    */
    readonly keyRefreshStrategy?: string;
    /**
    * The maximum clock skew is the maximum allowable time difference between the client and server. This time compensates for any small-time differences in the timestamps when verifying tokens
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#max_clock_skew_seconds OrgOidc#max_clock_skew_seconds}
    */
    readonly maxClockSkewSeconds?: number;
    /**
    * ID of the Organization that will have the OpenID Connect settings configured
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#org_id OrgOidc#org_id}
    */
    readonly orgId: string;
    /**
    * If you want to combine claims from 'userinfo_endpoint' and the ID Token, set this to 'true'. The identity providers do not provide all the required claims set in 'userinfo_endpoint'.By setting this argument to 'true', VMware Cloud Director can fetch and consume claims from both sources
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#prefer_id_token OrgOidc#prefer_id_token}
    */
    readonly preferIdToken?: boolean | cdktf.IResolvable;
    /**
    * A set of scopes to use with the OpenID Connect provider. They are used to authorize access to user details, by defining the permissions that the access tokens have to access user information. If 'wellknown_endpoint' is set, this attribute overrides the obtained scopes
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#scopes OrgOidc#scopes}
    */
    readonly scopes?: string[];
    /**
    * Customizes the label of the UI button of the login screen. Only available since VCD 10.5.1
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#ui_button_label OrgOidc#ui_button_label}
    */
    readonly uiButtonLabel?: string;
    /**
    * The user authorization endpoint of the OpenID Connect Identity Provider. If 'wellknown_endpoint' is set, this attribute overrides the obtained user authorization endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#user_authorization_endpoint OrgOidc#user_authorization_endpoint}
    */
    readonly userAuthorizationEndpoint?: string;
    /**
    * The user info endpoint of the OpenID Connect Identity Provider. If 'wellknown_endpoint' is set, this attribute overrides the obtained user info endpoint
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#userinfo_endpoint OrgOidc#userinfo_endpoint}
    */
    readonly userinfoEndpoint?: string;
    /**
    * Endpoint from the OpenID Connect Identity Provider that serves all the configuration values
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#wellknown_endpoint OrgOidc#wellknown_endpoint}
    */
    readonly wellknownEndpoint?: string;
    /**
    * claims_mapping block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#claims_mapping OrgOidc#claims_mapping}
    */
    readonly claimsMapping?: OrgOidcClaimsMapping;
    /**
    * key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#key OrgOidc#key}
    */
    readonly key?: OrgOidcKey[] | cdktf.IResolvable;
}
export interface OrgOidcClaimsMapping {
    /**
    * Email claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#email OrgOidc#email}
    */
    readonly email?: string;
    /**
    * First name claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#first_name OrgOidc#first_name}
    */
    readonly firstName?: string;
    /**
    * Full name claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#full_name OrgOidc#full_name}
    */
    readonly fullName?: string;
    /**
    * Groups claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#groups OrgOidc#groups}
    */
    readonly groups?: string;
    /**
    * Last name claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#last_name OrgOidc#last_name}
    */
    readonly lastName?: string;
    /**
    * Roles claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#roles OrgOidc#roles}
    */
    readonly roles?: string;
    /**
    * Subject claim mapping
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#subject OrgOidc#subject}
    */
    readonly subject?: string;
}
export declare function orgOidcClaimsMappingToTerraform(struct?: OrgOidcClaimsMappingOutputReference | OrgOidcClaimsMapping): any;
export declare function orgOidcClaimsMappingToHclTerraform(struct?: OrgOidcClaimsMappingOutputReference | OrgOidcClaimsMapping): any;
export declare class OrgOidcClaimsMappingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgOidcClaimsMapping | undefined;
    set internalValue(value: OrgOidcClaimsMapping | undefined);
    private _email?;
    get email(): string;
    set email(value: string);
    resetEmail(): void;
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    resetFirstName(): void;
    get firstNameInput(): string | undefined;
    private _fullName?;
    get fullName(): string;
    set fullName(value: string);
    resetFullName(): void;
    get fullNameInput(): string | undefined;
    private _groups?;
    get groups(): string;
    set groups(value: string);
    resetGroups(): void;
    get groupsInput(): string | undefined;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    resetLastName(): void;
    get lastNameInput(): string | undefined;
    private _roles?;
    get roles(): string;
    set roles(value: string);
    resetRoles(): void;
    get rolesInput(): string | undefined;
    private _subject?;
    get subject(): string;
    set subject(value: string);
    resetSubject(): void;
    get subjectInput(): string | undefined;
}
export interface OrgOidcKey {
    /**
    * Algorithm of the key, either RSA or EC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#algorithm OrgOidc#algorithm}
    */
    readonly algorithm: string;
    /**
    * The certificate contents
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#certificate OrgOidc#certificate}
    */
    readonly certificate: string;
    /**
    * Expiration date for the certificate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#expiration_date OrgOidc#expiration_date}
    */
    readonly expirationDate?: string;
    /**
    * ID of the key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#id OrgOidc#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function orgOidcKeyToTerraform(struct?: OrgOidcKey | cdktf.IResolvable): any;
export declare function orgOidcKeyToHclTerraform(struct?: OrgOidcKey | cdktf.IResolvable): any;
export declare class OrgOidcKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgOidcKey | cdktf.IResolvable | undefined;
    set internalValue(value: OrgOidcKey | cdktf.IResolvable | undefined);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    get algorithmInput(): string | undefined;
    private _certificate?;
    get certificate(): string;
    set certificate(value: string);
    get certificateInput(): string | undefined;
    private _expirationDate?;
    get expirationDate(): string;
    set expirationDate(value: string);
    resetExpirationDate(): void;
    get expirationDateInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export declare class OrgOidcKeyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgOidcKey[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgOidcKeyOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc vcd_org_oidc}
*/
export declare class OrgOidc extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_oidc";
    /**
    * Generates CDKTF code for importing a OrgOidc resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgOidc to import
    * @param importFromId The id of the existing OrgOidc that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgOidc to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_oidc vcd_org_oidc} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgOidcConfig
    */
    constructor(scope: Construct, id: string, config: OrgOidcConfig);
    private _accessTokenEndpoint?;
    get accessTokenEndpoint(): string;
    set accessTokenEndpoint(value: string);
    resetAccessTokenEndpoint(): void;
    get accessTokenEndpointInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    get clientSecretInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _issuerId?;
    get issuerId(): string;
    set issuerId(value: string);
    resetIssuerId(): void;
    get issuerIdInput(): string | undefined;
    private _keyExpireDurationHours?;
    get keyExpireDurationHours(): number;
    set keyExpireDurationHours(value: number);
    resetKeyExpireDurationHours(): void;
    get keyExpireDurationHoursInput(): number | undefined;
    private _keyRefreshEndpoint?;
    get keyRefreshEndpoint(): string;
    set keyRefreshEndpoint(value: string);
    resetKeyRefreshEndpoint(): void;
    get keyRefreshEndpointInput(): string | undefined;
    private _keyRefreshPeriodHours?;
    get keyRefreshPeriodHours(): number;
    set keyRefreshPeriodHours(value: number);
    resetKeyRefreshPeriodHours(): void;
    get keyRefreshPeriodHoursInput(): number | undefined;
    private _keyRefreshStrategy?;
    get keyRefreshStrategy(): string;
    set keyRefreshStrategy(value: string);
    resetKeyRefreshStrategy(): void;
    get keyRefreshStrategyInput(): string | undefined;
    private _maxClockSkewSeconds?;
    get maxClockSkewSeconds(): number;
    set maxClockSkewSeconds(value: number);
    resetMaxClockSkewSeconds(): void;
    get maxClockSkewSecondsInput(): number | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _preferIdToken?;
    get preferIdToken(): boolean | cdktf.IResolvable;
    set preferIdToken(value: boolean | cdktf.IResolvable);
    resetPreferIdToken(): void;
    get preferIdTokenInput(): boolean | cdktf.IResolvable | undefined;
    get redirectUri(): string;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _uiButtonLabel?;
    get uiButtonLabel(): string;
    set uiButtonLabel(value: string);
    resetUiButtonLabel(): void;
    get uiButtonLabelInput(): string | undefined;
    private _userAuthorizationEndpoint?;
    get userAuthorizationEndpoint(): string;
    set userAuthorizationEndpoint(value: string);
    resetUserAuthorizationEndpoint(): void;
    get userAuthorizationEndpointInput(): string | undefined;
    private _userinfoEndpoint?;
    get userinfoEndpoint(): string;
    set userinfoEndpoint(value: string);
    resetUserinfoEndpoint(): void;
    get userinfoEndpointInput(): string | undefined;
    private _wellknownEndpoint?;
    get wellknownEndpoint(): string;
    set wellknownEndpoint(value: string);
    resetWellknownEndpoint(): void;
    get wellknownEndpointInput(): string | undefined;
    private _claimsMapping;
    get claimsMapping(): OrgOidcClaimsMappingOutputReference;
    putClaimsMapping(value: OrgOidcClaimsMapping): void;
    resetClaimsMapping(): void;
    get claimsMappingInput(): OrgOidcClaimsMapping | undefined;
    private _key;
    get key(): OrgOidcKeyList;
    putKey(value: OrgOidcKey[] | cdktf.IResolvable): void;
    resetKey(): void;
    get keyInput(): cdktf.IResolvable | OrgOidcKey[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
