import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgVdcTemplateInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * If this flag is set to 'true', it forcefully deletes the VDC, only when delete_instantiated_vdc_on_removal=true
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#delete_force OrgVdcTemplateInstance#delete_force}
    */
    readonly deleteForce?: boolean | cdktf.IResolvable;
    /**
    * If this flag is set to 'true', removing this resource will attempt to delete the instantiated VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#delete_instantiated_vdc_on_removal OrgVdcTemplateInstance#delete_instantiated_vdc_on_removal}
    */
    readonly deleteInstantiatedVdcOnRemoval: boolean | cdktf.IResolvable;
    /**
    * If this flag is set to 'true', it recursively deletes the VDC, only when delete_instantiated_vdc_on_removal=true
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#delete_recursive OrgVdcTemplateInstance#delete_recursive}
    */
    readonly deleteRecursive?: boolean | cdktf.IResolvable;
    /**
    * Description of the VDC to be instantiated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#description OrgVdcTemplateInstance#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#id OrgVdcTemplateInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the VDC to be instantiated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#name OrgVdcTemplateInstance#name}
    */
    readonly name: string;
    /**
    * ID of the Organization where the VDC will be instantiated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#org_id OrgVdcTemplateInstance#org_id}
    */
    readonly orgId: string;
    /**
    * ID of the VDC template to instantiate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#org_vdc_template_id OrgVdcTemplateInstance#org_vdc_template_id}
    */
    readonly orgVdcTemplateId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance vcd_org_vdc_template_instance}
*/
export declare class OrgVdcTemplateInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_vdc_template_instance";
    /**
    * Generates CDKTF code for importing a OrgVdcTemplateInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgVdcTemplateInstance to import
    * @param importFromId The id of the existing OrgVdcTemplateInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgVdcTemplateInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template_instance vcd_org_vdc_template_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgVdcTemplateInstanceConfig
    */
    constructor(scope: Construct, id: string, config: OrgVdcTemplateInstanceConfig);
    private _deleteForce?;
    get deleteForce(): boolean | cdktf.IResolvable;
    set deleteForce(value: boolean | cdktf.IResolvable);
    resetDeleteForce(): void;
    get deleteForceInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteInstantiatedVdcOnRemoval?;
    get deleteInstantiatedVdcOnRemoval(): boolean | cdktf.IResolvable;
    set deleteInstantiatedVdcOnRemoval(value: boolean | cdktf.IResolvable);
    get deleteInstantiatedVdcOnRemovalInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteRecursive?;
    get deleteRecursive(): boolean | cdktf.IResolvable;
    set deleteRecursive(value: boolean | cdktf.IResolvable);
    resetDeleteRecursive(): void;
    get deleteRecursiveInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    private _orgVdcTemplateId?;
    get orgVdcTemplateId(): string;
    set orgVdcTemplateId(value: string);
    get orgVdcTemplateIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
