import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OrgVdcTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * Allocation model that the VDCs instantiated from this template will use. Must be one of: 'AllocationVApp', 'AllocationPool', 'ReservationPool' or 'Flex'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#allocation_model OrgVdcTemplate#allocation_model}
    */
    readonly allocationModel: string;
    /**
    * Description of the VDC Template as seen by the System administrator
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#description OrgVdcTemplate#description}
    */
    readonly description?: string;
    /**
    * If 'true', the VDCs instantiated from this template will have Fast provisioning enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#enable_fast_provisioning OrgVdcTemplate#enable_fast_provisioning}
    */
    readonly enableFastProvisioning?: boolean | cdktf.IResolvable;
    /**
    * If 'true', the VDCs instantiated from this template will have Thin provisioning enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#enable_thin_provisioning OrgVdcTemplate#enable_thin_provisioning}
    */
    readonly enableThinProvisioning?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#id OrgVdcTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the VDC Template as seen by the System administrator
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#name OrgVdcTemplate#name}
    */
    readonly name: string;
    /**
    * If set, specifies the Network pool for the instantiated VDCs. Otherwise, it is automatically chosen
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#network_pool_id OrgVdcTemplate#network_pool_id}
    */
    readonly networkPoolId?: string;
    /**
    * Quota for the NICs of the instantiated VDCs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#nic_quota OrgVdcTemplate#nic_quota}
    */
    readonly nicQuota?: number;
    /**
    * Quota for the provisioned networks of the instantiated VDCs
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#provisioned_network_quota OrgVdcTemplate#provisioned_network_quota}
    */
    readonly provisionedNetworkQuota?: number;
    /**
    * IDs of the Organizations that will be able to view and instantiate this VDC template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#readable_by_org_ids OrgVdcTemplate#readable_by_org_ids}
    */
    readonly readableByOrgIds?: string[];
    /**
    * Description of the VDC Template as seen by the tenants (organizations)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#tenant_description OrgVdcTemplate#tenant_description}
    */
    readonly tenantDescription?: string;
    /**
    * Name of the VDC Template as seen by the tenants (organizations)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#tenant_name OrgVdcTemplate#tenant_name}
    */
    readonly tenantName: string;
    /**
    * Quota for the VMs of the instantiated VDCs. 0 means unlimited
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#vm_quota OrgVdcTemplate#vm_quota}
    */
    readonly vmQuota?: number;
    /**
    * compute_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#compute_configuration OrgVdcTemplate#compute_configuration}
    */
    readonly computeConfiguration: OrgVdcTemplateComputeConfiguration;
    /**
    * edge_gateway block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#edge_gateway OrgVdcTemplate#edge_gateway}
    */
    readonly edgeGateway?: OrgVdcTemplateEdgeGateway;
    /**
    * provider_vdc block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#provider_vdc OrgVdcTemplate#provider_vdc}
    */
    readonly providerVdc: OrgVdcTemplateProviderVdc[] | cdktf.IResolvable;
    /**
    * storage_profile block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#storage_profile OrgVdcTemplate#storage_profile}
    */
    readonly storageProfile: OrgVdcTemplateStorageProfile[] | cdktf.IResolvable;
}
export interface OrgVdcTemplateComputeConfiguration {
    /**
    * AllocationPool, ReservationPool, Flex: The maximum amount of CPU, in MHz, available to the VMs running within the VDC that is instantiated from this template. Minimum is 256MHz
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#cpu_allocated OrgVdcTemplate#cpu_allocated}
    */
    readonly cpuAllocated?: number;
    /**
    * AllocationVApp, AllocationPool, Flex: The percentage of the CPU guaranteed to be available to VMs running within the VDC instantiated from this template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#cpu_guaranteed OrgVdcTemplate#cpu_guaranteed}
    */
    readonly cpuGuaranteed?: number;
    /**
    * AllocationVApp, ReservationPool, Flex: The limit amount of CPU, in MHz, of the VDC that is instantiated from this template. Minimum is 256MHz. 0 means unlimited
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#cpu_limit OrgVdcTemplate#cpu_limit}
    */
    readonly cpuLimit?: number;
    /**
    * AllocationVApp, AllocationPool, Flex: Specifies the clock frequency, in MHz, for any virtual CPU that is allocated to a VM. Minimum is 256MHz
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#cpu_speed OrgVdcTemplate#cpu_speed}
    */
    readonly cpuSpeed?: number;
    /**
    * Flex only: True if compute capacity can grow or shrink based on demand
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#elasticity OrgVdcTemplate#elasticity}
    */
    readonly elasticity?: boolean | cdktf.IResolvable;
    /**
    * Flex only: True if the instantiated VDC includes memory overhead into its accounting for admission control
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#include_vm_memory_overhead OrgVdcTemplate#include_vm_memory_overhead}
    */
    readonly includeVmMemoryOverhead?: boolean | cdktf.IResolvable;
    /**
    * AllocationPool, ReservationPool, Flex: The maximum amount of Memory, in MB, available to the VMs running within the VDC that is instantiated from this template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#memory_allocated OrgVdcTemplate#memory_allocated}
    */
    readonly memoryAllocated?: number;
    /**
    * AllocationVApp, AllocationPool, Flex: The percentage of the Memory guaranteed to be available to VMs running within the VDC instantiated from this template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#memory_guaranteed OrgVdcTemplate#memory_guaranteed}
    */
    readonly memoryGuaranteed?: number;
    /**
    * AllocationVApp, ReservationPool, Flex: The limit amount of Memory, in MB, of the VDC that is instantiated from this template. Minimum is 1024MB. 0 means unlimited
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#memory_limit OrgVdcTemplate#memory_limit}
    */
    readonly memoryLimit?: number;
}
export declare function orgVdcTemplateComputeConfigurationToTerraform(struct?: OrgVdcTemplateComputeConfigurationOutputReference | OrgVdcTemplateComputeConfiguration): any;
export declare function orgVdcTemplateComputeConfigurationToHclTerraform(struct?: OrgVdcTemplateComputeConfigurationOutputReference | OrgVdcTemplateComputeConfiguration): any;
export declare class OrgVdcTemplateComputeConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcTemplateComputeConfiguration | undefined;
    set internalValue(value: OrgVdcTemplateComputeConfiguration | undefined);
    private _cpuAllocated?;
    get cpuAllocated(): number;
    set cpuAllocated(value: number);
    resetCpuAllocated(): void;
    get cpuAllocatedInput(): number | undefined;
    private _cpuGuaranteed?;
    get cpuGuaranteed(): number;
    set cpuGuaranteed(value: number);
    resetCpuGuaranteed(): void;
    get cpuGuaranteedInput(): number | undefined;
    private _cpuLimit?;
    get cpuLimit(): number;
    set cpuLimit(value: number);
    resetCpuLimit(): void;
    get cpuLimitInput(): number | undefined;
    private _cpuSpeed?;
    get cpuSpeed(): number;
    set cpuSpeed(value: number);
    resetCpuSpeed(): void;
    get cpuSpeedInput(): number | undefined;
    private _elasticity?;
    get elasticity(): boolean | cdktf.IResolvable;
    set elasticity(value: boolean | cdktf.IResolvable);
    resetElasticity(): void;
    get elasticityInput(): boolean | cdktf.IResolvable | undefined;
    private _includeVmMemoryOverhead?;
    get includeVmMemoryOverhead(): boolean | cdktf.IResolvable;
    set includeVmMemoryOverhead(value: boolean | cdktf.IResolvable);
    resetIncludeVmMemoryOverhead(): void;
    get includeVmMemoryOverheadInput(): boolean | cdktf.IResolvable | undefined;
    private _memoryAllocated?;
    get memoryAllocated(): number;
    set memoryAllocated(value: number);
    resetMemoryAllocated(): void;
    get memoryAllocatedInput(): number | undefined;
    private _memoryGuaranteed?;
    get memoryGuaranteed(): number;
    set memoryGuaranteed(value: number);
    resetMemoryGuaranteed(): void;
    get memoryGuaranteedInput(): number | undefined;
    private _memoryLimit?;
    get memoryLimit(): number;
    set memoryLimit(value: number);
    resetMemoryLimit(): void;
    get memoryLimitInput(): number | undefined;
}
export interface OrgVdcTemplateEdgeGatewayStaticIpPool {
    /**
    * End address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#end_address OrgVdcTemplate#end_address}
    */
    readonly endAddress: string;
    /**
    * Start address of the IP range
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#start_address OrgVdcTemplate#start_address}
    */
    readonly startAddress: string;
}
export declare function orgVdcTemplateEdgeGatewayStaticIpPoolToTerraform(struct?: OrgVdcTemplateEdgeGatewayStaticIpPoolOutputReference | OrgVdcTemplateEdgeGatewayStaticIpPool): any;
export declare function orgVdcTemplateEdgeGatewayStaticIpPoolToHclTerraform(struct?: OrgVdcTemplateEdgeGatewayStaticIpPoolOutputReference | OrgVdcTemplateEdgeGatewayStaticIpPool): any;
export declare class OrgVdcTemplateEdgeGatewayStaticIpPoolOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcTemplateEdgeGatewayStaticIpPool | undefined;
    set internalValue(value: OrgVdcTemplateEdgeGatewayStaticIpPool | undefined);
    private _endAddress?;
    get endAddress(): string;
    set endAddress(value: string);
    get endAddressInput(): string | undefined;
    private _startAddress?;
    get startAddress(): string;
    set startAddress(value: string);
    get startAddressInput(): string | undefined;
}
export interface OrgVdcTemplateEdgeGateway {
    /**
    * Description of the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#description OrgVdcTemplate#description}
    */
    readonly description?: string;
    /**
    * Allocated IPs for the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#ip_allocation_count OrgVdcTemplate#ip_allocation_count}
    */
    readonly ipAllocationCount?: number;
    /**
    * Name of the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#name OrgVdcTemplate#name}
    */
    readonly name: string;
    /**
    * Description of the routed network to create with the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#routed_network_description OrgVdcTemplate#routed_network_description}
    */
    readonly routedNetworkDescription?: string;
    /**
    * CIDR of the Edge Gateway for the created routed network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#routed_network_gateway_cidr OrgVdcTemplate#routed_network_gateway_cidr}
    */
    readonly routedNetworkGatewayCidr: string;
    /**
    * Name of the routed network to create with the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#routed_network_name OrgVdcTemplate#routed_network_name}
    */
    readonly routedNetworkName: string;
    /**
    * static_ip_pool block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#static_ip_pool OrgVdcTemplate#static_ip_pool}
    */
    readonly staticIpPool?: OrgVdcTemplateEdgeGatewayStaticIpPool;
}
export declare function orgVdcTemplateEdgeGatewayToTerraform(struct?: OrgVdcTemplateEdgeGatewayOutputReference | OrgVdcTemplateEdgeGateway): any;
export declare function orgVdcTemplateEdgeGatewayToHclTerraform(struct?: OrgVdcTemplateEdgeGatewayOutputReference | OrgVdcTemplateEdgeGateway): any;
export declare class OrgVdcTemplateEdgeGatewayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OrgVdcTemplateEdgeGateway | undefined;
    set internalValue(value: OrgVdcTemplateEdgeGateway | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _ipAllocationCount?;
    get ipAllocationCount(): number;
    set ipAllocationCount(value: number);
    resetIpAllocationCount(): void;
    get ipAllocationCountInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _routedNetworkDescription?;
    get routedNetworkDescription(): string;
    set routedNetworkDescription(value: string);
    resetRoutedNetworkDescription(): void;
    get routedNetworkDescriptionInput(): string | undefined;
    private _routedNetworkGatewayCidr?;
    get routedNetworkGatewayCidr(): string;
    set routedNetworkGatewayCidr(value: string);
    get routedNetworkGatewayCidrInput(): string | undefined;
    private _routedNetworkName?;
    get routedNetworkName(): string;
    set routedNetworkName(value: string);
    get routedNetworkNameInput(): string | undefined;
    private _staticIpPool;
    get staticIpPool(): OrgVdcTemplateEdgeGatewayStaticIpPoolOutputReference;
    putStaticIpPool(value: OrgVdcTemplateEdgeGatewayStaticIpPool): void;
    resetStaticIpPool(): void;
    get staticIpPoolInput(): OrgVdcTemplateEdgeGatewayStaticIpPool | undefined;
}
export interface OrgVdcTemplateProviderVdc {
    /**
    * ID of the External network that the VDCs instantiated from this template will use
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#external_network_id OrgVdcTemplate#external_network_id}
    */
    readonly externalNetworkId: string;
    /**
    * ID of the Edge Cluster that the VDCs instantiated from this template will use with the Edge Gateway
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#gateway_edge_cluster_id OrgVdcTemplate#gateway_edge_cluster_id}
    */
    readonly gatewayEdgeClusterId?: string;
    /**
    * ID of Provider VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#id OrgVdcTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * ID of the Edge Cluster that the VDCs instantiated from this template will use for services
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#services_edge_cluster_id OrgVdcTemplate#services_edge_cluster_id}
    */
    readonly servicesEdgeClusterId?: string;
}
export declare function orgVdcTemplateProviderVdcToTerraform(struct?: OrgVdcTemplateProviderVdc | cdktf.IResolvable): any;
export declare function orgVdcTemplateProviderVdcToHclTerraform(struct?: OrgVdcTemplateProviderVdc | cdktf.IResolvable): any;
export declare class OrgVdcTemplateProviderVdcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgVdcTemplateProviderVdc | cdktf.IResolvable | undefined;
    set internalValue(value: OrgVdcTemplateProviderVdc | cdktf.IResolvable | undefined);
    private _externalNetworkId?;
    get externalNetworkId(): string;
    set externalNetworkId(value: string);
    get externalNetworkIdInput(): string | undefined;
    private _gatewayEdgeClusterId?;
    get gatewayEdgeClusterId(): string;
    set gatewayEdgeClusterId(value: string);
    resetGatewayEdgeClusterId(): void;
    get gatewayEdgeClusterIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _servicesEdgeClusterId?;
    get servicesEdgeClusterId(): string;
    set servicesEdgeClusterId(value: string);
    resetServicesEdgeClusterId(): void;
    get servicesEdgeClusterIdInput(): string | undefined;
}
export declare class OrgVdcTemplateProviderVdcList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgVdcTemplateProviderVdc[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgVdcTemplateProviderVdcOutputReference;
}
export interface OrgVdcTemplateStorageProfile {
    /**
    * True if this is default storage profile for the VDCs instantiated from this template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#default OrgVdcTemplate#default}
    */
    readonly default: boolean | cdktf.IResolvable;
    /**
    * Storage limit for the VDCs instantiated from this template, in Megabytes. 0 means unlimited
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#limit OrgVdcTemplate#limit}
    */
    readonly limit: number;
    /**
    * Name of Provider VDC storage profile to use for the VDCs instantiated from this template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#name OrgVdcTemplate#name}
    */
    readonly name: string;
}
export declare function orgVdcTemplateStorageProfileToTerraform(struct?: OrgVdcTemplateStorageProfile | cdktf.IResolvable): any;
export declare function orgVdcTemplateStorageProfileToHclTerraform(struct?: OrgVdcTemplateStorageProfile | cdktf.IResolvable): any;
export declare class OrgVdcTemplateStorageProfileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OrgVdcTemplateStorageProfile | cdktf.IResolvable | undefined;
    set internalValue(value: OrgVdcTemplateStorageProfile | cdktf.IResolvable | undefined);
    private _default?;
    get default(): boolean | cdktf.IResolvable;
    set default(value: boolean | cdktf.IResolvable);
    get defaultInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class OrgVdcTemplateStorageProfileList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OrgVdcTemplateStorageProfile[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OrgVdcTemplateStorageProfileOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template vcd_org_vdc_template}
*/
export declare class OrgVdcTemplate extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_org_vdc_template";
    /**
    * Generates CDKTF code for importing a OrgVdcTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OrgVdcTemplate to import
    * @param importFromId The id of the existing OrgVdcTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OrgVdcTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/org_vdc_template vcd_org_vdc_template} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OrgVdcTemplateConfig
    */
    constructor(scope: Construct, id: string, config: OrgVdcTemplateConfig);
    private _allocationModel?;
    get allocationModel(): string;
    set allocationModel(value: string);
    get allocationModelInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enableFastProvisioning?;
    get enableFastProvisioning(): boolean | cdktf.IResolvable;
    set enableFastProvisioning(value: boolean | cdktf.IResolvable);
    resetEnableFastProvisioning(): void;
    get enableFastProvisioningInput(): boolean | cdktf.IResolvable | undefined;
    private _enableThinProvisioning?;
    get enableThinProvisioning(): boolean | cdktf.IResolvable;
    set enableThinProvisioning(value: boolean | cdktf.IResolvable);
    resetEnableThinProvisioning(): void;
    get enableThinProvisioningInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _networkPoolId?;
    get networkPoolId(): string;
    set networkPoolId(value: string);
    resetNetworkPoolId(): void;
    get networkPoolIdInput(): string | undefined;
    private _nicQuota?;
    get nicQuota(): number;
    set nicQuota(value: number);
    resetNicQuota(): void;
    get nicQuotaInput(): number | undefined;
    private _provisionedNetworkQuota?;
    get provisionedNetworkQuota(): number;
    set provisionedNetworkQuota(value: number);
    resetProvisionedNetworkQuota(): void;
    get provisionedNetworkQuotaInput(): number | undefined;
    private _readableByOrgIds?;
    get readableByOrgIds(): string[];
    set readableByOrgIds(value: string[]);
    resetReadableByOrgIds(): void;
    get readableByOrgIdsInput(): string[] | undefined;
    private _tenantDescription?;
    get tenantDescription(): string;
    set tenantDescription(value: string);
    resetTenantDescription(): void;
    get tenantDescriptionInput(): string | undefined;
    private _tenantName?;
    get tenantName(): string;
    set tenantName(value: string);
    get tenantNameInput(): string | undefined;
    private _vmQuota?;
    get vmQuota(): number;
    set vmQuota(value: number);
    resetVmQuota(): void;
    get vmQuotaInput(): number | undefined;
    private _computeConfiguration;
    get computeConfiguration(): OrgVdcTemplateComputeConfigurationOutputReference;
    putComputeConfiguration(value: OrgVdcTemplateComputeConfiguration): void;
    get computeConfigurationInput(): OrgVdcTemplateComputeConfiguration | undefined;
    private _edgeGateway;
    get edgeGateway(): OrgVdcTemplateEdgeGatewayOutputReference;
    putEdgeGateway(value: OrgVdcTemplateEdgeGateway): void;
    resetEdgeGateway(): void;
    get edgeGatewayInput(): OrgVdcTemplateEdgeGateway | undefined;
    private _providerVdc;
    get providerVdc(): OrgVdcTemplateProviderVdcList;
    putProviderVdc(value: OrgVdcTemplateProviderVdc[] | cdktf.IResolvable): void;
    get providerVdcInput(): cdktf.IResolvable | OrgVdcTemplateProviderVdc[] | undefined;
    private _storageProfile;
    get storageProfile(): OrgVdcTemplateStorageProfileList;
    putStorageProfile(value: OrgVdcTemplateStorageProfile[] | cdktf.IResolvable): void;
    get storageProfileInput(): cdktf.IResolvable | OrgVdcTemplateStorageProfile[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
