import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RdeInterfaceBehaviorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Useful to update execution properties marked with _secure_ and _internal_,as these are not retrievable from VCD, so they are not saved in state. Setting this to 'true' will make the Providerto ask for updates whenever there is a secure property in the execution of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#always_update_secure_execution_properties RdeInterfaceBehavior#always_update_secure_execution_properties}
    */
    readonly alwaysUpdateSecureExecutionProperties?: boolean | cdktf.IResolvable;
    /**
    * A description specifying the contract of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#description RdeInterfaceBehavior#description}
    */
    readonly description?: string;
    /**
    * Execution map of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#execution RdeInterfaceBehavior#execution}
    */
    readonly execution?: {
        [key: string]: string;
    };
    /**
    * Execution of the Behavior in JSON format, that allows to define complex Behavior executions
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#execution_json RdeInterfaceBehavior#execution_json}
    */
    readonly executionJson?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#id RdeInterfaceBehavior#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#name RdeInterfaceBehavior#name}
    */
    readonly name: string;
    /**
    * The ID of the RDE Interface that owns the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#rde_interface_id RdeInterfaceBehavior#rde_interface_id}
    */
    readonly rdeInterfaceId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior vcd_rde_interface_behavior}
*/
export declare class RdeInterfaceBehavior extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rde_interface_behavior";
    /**
    * Generates CDKTF code for importing a RdeInterfaceBehavior resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RdeInterfaceBehavior to import
    * @param importFromId The id of the existing RdeInterfaceBehavior that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RdeInterfaceBehavior to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_interface_behavior vcd_rde_interface_behavior} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RdeInterfaceBehaviorConfig
    */
    constructor(scope: Construct, id: string, config: RdeInterfaceBehaviorConfig);
    private _alwaysUpdateSecureExecutionProperties?;
    get alwaysUpdateSecureExecutionProperties(): boolean | cdktf.IResolvable;
    set alwaysUpdateSecureExecutionProperties(value: boolean | cdktf.IResolvable);
    resetAlwaysUpdateSecureExecutionProperties(): void;
    get alwaysUpdateSecureExecutionPropertiesInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _execution?;
    get execution(): {
        [key: string]: string;
    };
    set execution(value: {
        [key: string]: string;
    });
    resetExecution(): void;
    get executionInput(): {
        [key: string]: string;
    } | undefined;
    private _executionJson?;
    get executionJson(): string;
    set executionJson(value: string);
    resetExecutionJson(): void;
    get executionJsonInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rdeInterfaceId?;
    get rdeInterfaceId(): string;
    set rdeInterfaceId(value: string);
    get rdeInterfaceIdInput(): string | undefined;
    get ref(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
