import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RdeTypeBehaviorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Useful to update execution properties marked with _secure_ and _internal_,as these are not retrievable from VCD, so they are not saved in state. Setting this to 'true' will make the Providerto ask for updates whenever there is a secure property in the execution of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#always_update_secure_execution_properties RdeTypeBehavior#always_update_secure_execution_properties}
    */
    readonly alwaysUpdateSecureExecutionProperties?: boolean | cdktf.IResolvable;
    /**
    * The description of the contract of the overridden Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#description RdeTypeBehavior#description}
    */
    readonly description?: string;
    /**
    * Execution map of the Behavior
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#execution RdeTypeBehavior#execution}
    */
    readonly execution?: {
        [key: string]: string;
    };
    /**
    * Execution of the Behavior in JSON format, that allows to define complex Behavior executions
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#execution_json RdeTypeBehavior#execution_json}
    */
    readonly executionJson?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#id RdeTypeBehavior#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the original RDE Interface Behavior to override
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#rde_interface_behavior_id RdeTypeBehavior#rde_interface_behavior_id}
    */
    readonly rdeInterfaceBehaviorId: string;
    /**
    * The ID of the RDE Type that owns the Behavior override
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#rde_type_id RdeTypeBehavior#rde_type_id}
    */
    readonly rdeTypeId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior vcd_rde_type_behavior}
*/
export declare class RdeTypeBehavior extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_rde_type_behavior";
    /**
    * Generates CDKTF code for importing a RdeTypeBehavior resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RdeTypeBehavior to import
    * @param importFromId The id of the existing RdeTypeBehavior that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RdeTypeBehavior to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/rde_type_behavior vcd_rde_type_behavior} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RdeTypeBehaviorConfig
    */
    constructor(scope: Construct, id: string, config: RdeTypeBehaviorConfig);
    private _alwaysUpdateSecureExecutionProperties?;
    get alwaysUpdateSecureExecutionProperties(): boolean | cdktf.IResolvable;
    set alwaysUpdateSecureExecutionProperties(value: boolean | cdktf.IResolvable);
    resetAlwaysUpdateSecureExecutionProperties(): void;
    get alwaysUpdateSecureExecutionPropertiesInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _execution?;
    get execution(): {
        [key: string]: string;
    };
    set execution(value: {
        [key: string]: string;
    });
    resetExecution(): void;
    get executionInput(): {
        [key: string]: string;
    } | undefined;
    private _executionJson?;
    get executionJson(): string;
    set executionJson(value: string);
    resetExecutionJson(): void;
    get executionJsonInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _rdeInterfaceBehaviorId?;
    get rdeInterfaceBehaviorId(): string;
    set rdeInterfaceBehaviorId(value: string);
    get rdeInterfaceBehaviorIdInput(): string | undefined;
    private _rdeTypeId?;
    get rdeTypeId(): string;
    set rdeTypeId(value: string);
    get rdeTypeIdInput(): string | undefined;
    get ref(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
