import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SolutionAddOnInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Defines if EULA is accepted. `false` will return an error and print EULA
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#accept_eula SolutionAddOnInstance#accept_eula}
    */
    readonly acceptEula: boolean | cdktf.IResolvable;
    /**
    * Parent Solution Add-On ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#add_on_id SolutionAddOnInstance#add_on_id}
    */
    readonly addOnId: string;
    /**
    * Key value map for deletion of Solution Add-On Instance
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#delete_input SolutionAddOnInstance#delete_input}
    */
    readonly deleteInput?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#id SolutionAddOnInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Key value map of Solution Add-On Instance
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#input SolutionAddOnInstance#input}
    */
    readonly input?: {
        [key: string]: string;
    };
    /**
    * Solution Add-On Instance Name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#name SolutionAddOnInstance#name}
    */
    readonly name: string;
    /**
    * Defines if all or only required inputs should be validated
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#validate_only_required_inputs SolutionAddOnInstance#validate_only_required_inputs}
    */
    readonly validateOnlyRequiredInputs?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance vcd_solution_add_on_instance}
*/
export declare class SolutionAddOnInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_solution_add_on_instance";
    /**
    * Generates CDKTF code for importing a SolutionAddOnInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SolutionAddOnInstance to import
    * @param importFromId The id of the existing SolutionAddOnInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SolutionAddOnInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on_instance vcd_solution_add_on_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SolutionAddOnInstanceConfig
    */
    constructor(scope: Construct, id: string, config: SolutionAddOnInstanceConfig);
    private _acceptEula?;
    get acceptEula(): boolean | cdktf.IResolvable;
    set acceptEula(value: boolean | cdktf.IResolvable);
    get acceptEulaInput(): boolean | cdktf.IResolvable | undefined;
    private _addOnId?;
    get addOnId(): string;
    set addOnId(value: string);
    get addOnIdInput(): string | undefined;
    private _deleteInput?;
    get deleteInput(): {
        [key: string]: string;
    };
    set deleteInput(value: {
        [key: string]: string;
    });
    resetDeleteInput(): void;
    get deleteInputInput(): {
        [key: string]: string;
    } | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _input?;
    get input(): {
        [key: string]: string;
    };
    set input(value: {
        [key: string]: string;
    });
    resetInput(): void;
    get inputInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get rdeState(): string;
    private _validateOnlyRequiredInputs?;
    get validateOnlyRequiredInputs(): boolean | cdktf.IResolvable;
    set validateOnlyRequiredInputs(value: boolean | cdktf.IResolvable);
    resetValidateOnlyRequiredInputs(): void;
    get validateOnlyRequiredInputsInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
