import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SolutionAddOnConfig extends cdktf.TerraformMetaArguments {
    /**
    * Absolute or relative path to Solution Add-On ISO file available locally
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on#add_on_path SolutionAddOn#add_on_path}
    */
    readonly addOnPath: string;
    /**
    * Defines if the resource should automatically trust Solution Add-On certificate
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on#auto_trust_certificate SolutionAddOn#auto_trust_certificate}
    */
    readonly autoTrustCertificate?: boolean | cdktf.IResolvable;
    /**
    * Solution Add-On Catalog Item ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on#catalog_item_id SolutionAddOn#catalog_item_id}
    */
    readonly catalogItemId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on#id SolutionAddOn#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on vcd_solution_add_on}
*/
export declare class SolutionAddOn extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_solution_add_on";
    /**
    * Generates CDKTF code for importing a SolutionAddOn resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SolutionAddOn to import
    * @param importFromId The id of the existing SolutionAddOn that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SolutionAddOn to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_add_on vcd_solution_add_on} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SolutionAddOnConfig
    */
    constructor(scope: Construct, id: string, config: SolutionAddOnConfig);
    private _addOnPath?;
    get addOnPath(): string;
    set addOnPath(value: string);
    get addOnPathInput(): string | undefined;
    private _autoTrustCertificate?;
    get autoTrustCertificate(): boolean | cdktf.IResolvable;
    set autoTrustCertificate(value: boolean | cdktf.IResolvable);
    resetAutoTrustCertificate(): void;
    get autoTrustCertificateInput(): boolean | cdktf.IResolvable | undefined;
    private _catalogItemId?;
    get catalogItemId(): string;
    set catalogItemId(value: string);
    get catalogItemIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    get rdeState(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
