import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SolutionLandingZoneConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of organization to use, optional if defined at provider level. Useful when connected as sysadmin working across different organizations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#org SolutionLandingZone#org}
    */
    readonly org?: string;
    /**
    * catalog block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#catalog SolutionLandingZone#catalog}
    */
    readonly catalog: SolutionLandingZoneCatalog;
    /**
    * vdc block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#vdc SolutionLandingZone#vdc}
    */
    readonly vdc: SolutionLandingZoneVdc[] | cdktf.IResolvable;
}
export interface SolutionLandingZoneCatalog {
    /**
    * Capability set for catalog
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#capabilities SolutionLandingZone#capabilities}
    */
    readonly capabilities?: string[];
    /**
    * ID of catalog
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function solutionLandingZoneCatalogToTerraform(struct?: SolutionLandingZoneCatalogOutputReference | SolutionLandingZoneCatalog): any;
export declare function solutionLandingZoneCatalogToHclTerraform(struct?: SolutionLandingZoneCatalogOutputReference | SolutionLandingZoneCatalog): any;
export declare class SolutionLandingZoneCatalogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SolutionLandingZoneCatalog | undefined;
    set internalValue(value: SolutionLandingZoneCatalog | undefined);
    private _capabilities?;
    get capabilities(): string[];
    set capabilities(value: string[]);
    resetCapabilities(): void;
    get capabilitiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get name(): string;
}
export interface SolutionLandingZoneVdcComputePolicy {
    /**
    * Set of capabilities for Compute Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#capabilities SolutionLandingZone#capabilities}
    */
    readonly capabilities?: string[];
    /**
    * ID of Compute Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Boolean value that marks if this Compute Policy should be default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#is_default SolutionLandingZone#is_default}
    */
    readonly isDefault?: boolean | cdktf.IResolvable;
}
export declare function solutionLandingZoneVdcComputePolicyToTerraform(struct?: SolutionLandingZoneVdcComputePolicy | cdktf.IResolvable): any;
export declare function solutionLandingZoneVdcComputePolicyToHclTerraform(struct?: SolutionLandingZoneVdcComputePolicy | cdktf.IResolvable): any;
export declare class SolutionLandingZoneVdcComputePolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SolutionLandingZoneVdcComputePolicy | cdktf.IResolvable | undefined;
    set internalValue(value: SolutionLandingZoneVdcComputePolicy | cdktf.IResolvable | undefined);
    private _capabilities?;
    get capabilities(): string[];
    set capabilities(value: string[]);
    resetCapabilities(): void;
    get capabilitiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _isDefault?;
    get isDefault(): boolean | cdktf.IResolvable;
    set isDefault(value: boolean | cdktf.IResolvable);
    resetIsDefault(): void;
    get isDefaultInput(): boolean | cdktf.IResolvable | undefined;
    get name(): string;
}
export declare class SolutionLandingZoneVdcComputePolicyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SolutionLandingZoneVdcComputePolicy[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SolutionLandingZoneVdcComputePolicyOutputReference;
}
export interface SolutionLandingZoneVdcOrgVdcNetwork {
    /**
    * Set of capabilities for Org VDC Network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#capabilities SolutionLandingZone#capabilities}
    */
    readonly capabilities?: string[];
    /**
    * ID of Org VDC Network
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Boolean value that marks if this Org VDC Network should be default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#is_default SolutionLandingZone#is_default}
    */
    readonly isDefault?: boolean | cdktf.IResolvable;
}
export declare function solutionLandingZoneVdcOrgVdcNetworkToTerraform(struct?: SolutionLandingZoneVdcOrgVdcNetwork | cdktf.IResolvable): any;
export declare function solutionLandingZoneVdcOrgVdcNetworkToHclTerraform(struct?: SolutionLandingZoneVdcOrgVdcNetwork | cdktf.IResolvable): any;
export declare class SolutionLandingZoneVdcOrgVdcNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SolutionLandingZoneVdcOrgVdcNetwork | cdktf.IResolvable | undefined;
    set internalValue(value: SolutionLandingZoneVdcOrgVdcNetwork | cdktf.IResolvable | undefined);
    private _capabilities?;
    get capabilities(): string[];
    set capabilities(value: string[]);
    resetCapabilities(): void;
    get capabilitiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _isDefault?;
    get isDefault(): boolean | cdktf.IResolvable;
    set isDefault(value: boolean | cdktf.IResolvable);
    resetIsDefault(): void;
    get isDefaultInput(): boolean | cdktf.IResolvable | undefined;
    get name(): string;
}
export declare class SolutionLandingZoneVdcOrgVdcNetworkList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SolutionLandingZoneVdcOrgVdcNetwork[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SolutionLandingZoneVdcOrgVdcNetworkOutputReference;
}
export interface SolutionLandingZoneVdcStoragePolicy {
    /**
    * Set of capabilities for Storage Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#capabilities SolutionLandingZone#capabilities}
    */
    readonly capabilities?: string[];
    /**
    * ID of Storage Policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Boolean value that marks if this Storage Policy should be default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#is_default SolutionLandingZone#is_default}
    */
    readonly isDefault?: boolean | cdktf.IResolvable;
}
export declare function solutionLandingZoneVdcStoragePolicyToTerraform(struct?: SolutionLandingZoneVdcStoragePolicy | cdktf.IResolvable): any;
export declare function solutionLandingZoneVdcStoragePolicyToHclTerraform(struct?: SolutionLandingZoneVdcStoragePolicy | cdktf.IResolvable): any;
export declare class SolutionLandingZoneVdcStoragePolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SolutionLandingZoneVdcStoragePolicy | cdktf.IResolvable | undefined;
    set internalValue(value: SolutionLandingZoneVdcStoragePolicy | cdktf.IResolvable | undefined);
    private _capabilities?;
    get capabilities(): string[];
    set capabilities(value: string[]);
    resetCapabilities(): void;
    get capabilitiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _isDefault?;
    get isDefault(): boolean | cdktf.IResolvable;
    set isDefault(value: boolean | cdktf.IResolvable);
    resetIsDefault(): void;
    get isDefaultInput(): boolean | cdktf.IResolvable | undefined;
    get name(): string;
}
export declare class SolutionLandingZoneVdcStoragePolicyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SolutionLandingZoneVdcStoragePolicy[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SolutionLandingZoneVdcStoragePolicyOutputReference;
}
export interface SolutionLandingZoneVdc {
    /**
    * Capability set for VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#capabilities SolutionLandingZone#capabilities}
    */
    readonly capabilities?: string[];
    /**
    * ID of VDC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#id SolutionLandingZone#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Defines if the entity should be considered as default
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#is_default SolutionLandingZone#is_default}
    */
    readonly isDefault: boolean | cdktf.IResolvable;
    /**
    * compute_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#compute_policy SolutionLandingZone#compute_policy}
    */
    readonly computePolicy: SolutionLandingZoneVdcComputePolicy[] | cdktf.IResolvable;
    /**
    * org_vdc_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#org_vdc_network SolutionLandingZone#org_vdc_network}
    */
    readonly orgVdcNetwork: SolutionLandingZoneVdcOrgVdcNetwork[] | cdktf.IResolvable;
    /**
    * storage_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#storage_policy SolutionLandingZone#storage_policy}
    */
    readonly storagePolicy: SolutionLandingZoneVdcStoragePolicy[] | cdktf.IResolvable;
}
export declare function solutionLandingZoneVdcToTerraform(struct?: SolutionLandingZoneVdc | cdktf.IResolvable): any;
export declare function solutionLandingZoneVdcToHclTerraform(struct?: SolutionLandingZoneVdc | cdktf.IResolvable): any;
export declare class SolutionLandingZoneVdcOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SolutionLandingZoneVdc | cdktf.IResolvable | undefined;
    set internalValue(value: SolutionLandingZoneVdc | cdktf.IResolvable | undefined);
    private _capabilities?;
    get capabilities(): string[];
    set capabilities(value: string[]);
    resetCapabilities(): void;
    get capabilitiesInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _isDefault?;
    get isDefault(): boolean | cdktf.IResolvable;
    set isDefault(value: boolean | cdktf.IResolvable);
    get isDefaultInput(): boolean | cdktf.IResolvable | undefined;
    get name(): string;
    private _computePolicy;
    get computePolicy(): SolutionLandingZoneVdcComputePolicyList;
    putComputePolicy(value: SolutionLandingZoneVdcComputePolicy[] | cdktf.IResolvable): void;
    get computePolicyInput(): cdktf.IResolvable | SolutionLandingZoneVdcComputePolicy[] | undefined;
    private _orgVdcNetwork;
    get orgVdcNetwork(): SolutionLandingZoneVdcOrgVdcNetworkList;
    putOrgVdcNetwork(value: SolutionLandingZoneVdcOrgVdcNetwork[] | cdktf.IResolvable): void;
    get orgVdcNetworkInput(): cdktf.IResolvable | SolutionLandingZoneVdcOrgVdcNetwork[] | undefined;
    private _storagePolicy;
    get storagePolicy(): SolutionLandingZoneVdcStoragePolicyList;
    putStoragePolicy(value: SolutionLandingZoneVdcStoragePolicy[] | cdktf.IResolvable): void;
    get storagePolicyInput(): cdktf.IResolvable | SolutionLandingZoneVdcStoragePolicy[] | undefined;
}
export declare class SolutionLandingZoneVdcList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SolutionLandingZoneVdc[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SolutionLandingZoneVdcOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone vcd_solution_landing_zone}
*/
export declare class SolutionLandingZone extends cdktf.TerraformResource {
    static readonly tfResourceType = "vcd_solution_landing_zone";
    /**
    * Generates CDKTF code for importing a SolutionLandingZone resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SolutionLandingZone to import
    * @param importFromId The id of the existing SolutionLandingZone that should be imported. Refer to the {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SolutionLandingZone to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/vmware/vcd/3.14.1/docs/resources/solution_landing_zone vcd_solution_landing_zone} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SolutionLandingZoneConfig
    */
    constructor(scope: Construct, id: string, config: SolutionLandingZoneConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _org?;
    get org(): string;
    set org(value: string);
    resetOrg(): void;
    get orgInput(): string | undefined;
    get state(): string;
    private _catalog;
    get catalog(): SolutionLandingZoneCatalogOutputReference;
    putCatalog(value: SolutionLandingZoneCatalog): void;
    get catalogInput(): SolutionLandingZoneCatalog | undefined;
    private _vdc;
    get vdc(): SolutionLandingZoneVdcList;
    putVdc(value: SolutionLandingZoneVdc[] | cdktf.IResolvable): void;
    get vdcInput(): cdktf.IResolvable | SolutionLandingZoneVdc[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
